package com.example.hangry.controller;

import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import java.util.List;
import com.example.hangry.*;
import com.example.hangry.services.LikeService;
@RestController
@RequestMapping("/api/likes")
@CrossOrigin(origins = "*")
public class LikeController {

    private final LikeService likeService;

    public LikeController(LikeService likeService) {
        this.likeService = likeService;
    }

    // Rezept liken
    @PostMapping("/{userId}/{recipeId}")
    public ResponseEntity<String> likeRecipe(@PathVariable Long userId, @PathVariable Long recipeId) {
        boolean liked = likeService.likeRecipe(userId, recipeId);
        return liked ? ResponseEntity.ok("Rezept geliked") : ResponseEntity.badRequest().body("Bereits geliked");
    }

    // Rezept entliken
    @DeleteMapping("/{userId}/{recipeId}")
    public ResponseEntity<String> unlikeRecipe(@PathVariable Long userId, @PathVariable Long recipeId) {
        boolean unliked = likeService.unlikeRecipe(userId, recipeId);
        return unliked ? ResponseEntity.ok("Like entfernt") : ResponseEntity.badRequest().body("Like existiert nicht");
    }

    // Anzahl der Likes für ein Rezept abrufen
    @GetMapping("/count/{recipeId}")
    public ResponseEntity<Long> getLikeCount(@PathVariable Long recipeId) {
        return ResponseEntity.ok(likeService.getLikeCount(recipeId));
    }

    // Alle geliketen Rezepte eines Users abrufen
    @GetMapping("/user/{userId}")
    public ResponseEntity<List<Recipe>> getLikedRecipes(@PathVariable Long userId) {
        return ResponseEntity.ok(likeService.getLikedRecipes(userId));
    }
}

