package com.example.hangry.controller;

import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import java.util.Optional;

import com.example.hangry.*;
import com.example.hangry.services.RecipeService;
@RestController
@RequestMapping("/api/recipes")
@CrossOrigin(origins = "*") // Erlaubt CORS für alle Domains, kann angepasst werden
public class RecipeController {

    private final RecipeService recipeService;

    public RecipeController(RecipeService recipeService) {
        this.recipeService = recipeService;
    }

    // Alle Rezepte mit Pagination abrufen
    @GetMapping
    public Page<Recipe> getAllRecipes(Pageable pageable) {
        return recipeService.getAllRecipes(pageable);
    }

    // Einzelnes Rezept nach ID abrufen
    @GetMapping("/{id}")
    public ResponseEntity<Recipe> getRecipeById(@PathVariable Long id) {
        Optional<Recipe> recipe = recipeService.getRecipeById(id);
        return recipe.map(ResponseEntity::ok).orElseGet(() -> ResponseEntity.notFound().build());
    }

    // Neues Rezept erstellen
    @PostMapping
    public ResponseEntity<Recipe> createRecipe(@RequestBody Recipe recipe) {
        Recipe savedRecipe = recipeService.createRecipe(recipe);
        return ResponseEntity.status(HttpStatus.CREATED).body(savedRecipe);
    }

    // Rezept aktualisieren
    @PutMapping("/{id}")
    public ResponseEntity<Recipe> updateRecipe(@PathVariable Long id, @RequestBody Recipe recipe) {
        Optional<Recipe> updatedRecipe = recipeService.updateRecipe(id, recipe);
        return updatedRecipe.map(ResponseEntity::ok).orElseGet(() -> ResponseEntity.notFound().build());
    }

    // Rezept löschen
    @DeleteMapping("/{id}")
    public ResponseEntity<Void> deleteRecipe(@PathVariable Long id) {
        if (recipeService.deleteRecipe(id)) {
            return ResponseEntity.noContent().build();
        } else {
            return ResponseEntity.notFound().build();
        }
    }
    //Endpunkt: Filter nach Kategorie (z. B. "/api/recipes/filter/category?category=vegan")
    @GetMapping("/filter/category")
    public Page<Recipe> getRecipesByCategory(@RequestParam String category, Pageable pageable) {
        return recipeService.getRecipesByCategory(category, pageable);
    }

    // Endpunkt: Filter nach Zutat (z. B. "/api/recipes/filter/ingredient?ingredient=tomate")
    @GetMapping("/filter/ingredient")
    public Page<Recipe> getRecipesByIngredient(@RequestParam String ingredient, Pageable pageable) {
        return recipeService.getRecipesByIngredient(ingredient, pageable);
    }
}
