package com.example.hangry.services;

import org.springframework.stereotype.Service;
import java.util.Set;
import java.util.stream.Collectors;
import com.example.hangry.*;
@Service
public class GroupRecipeService {

    private final GroupRepository groupRepository;
    private final RecipeRepository recipeRepository;
    private final GroupRecipeRepository groupRecipeRepository;

    public GroupRecipeService(GroupRepository groupRepository, RecipeRepository recipeRepository, GroupRecipeRepository groupRecipeRepository) {
        this.groupRepository = groupRepository;
        this.recipeRepository = recipeRepository;
        this.groupRecipeRepository = groupRecipeRepository;
    }

    // Rezept mit Gruppe teilen
    public boolean shareRecipeWithGroup(Long groupId, Long recipeId) {
        Group group = groupRepository.findById(groupId)
                .orElseThrow(() -> new RuntimeException("Gruppe nicht gefunden"));
        Recipe recipe = recipeRepository.findById(recipeId)
                .orElseThrow(() -> new RuntimeException("Rezept nicht gefunden"));

        GroupRecipe groupRecipe = new GroupRecipe(group, recipe);
        groupRecipeRepository.save(groupRecipe);
        return true;
    }

    // Alle Rezepte einer Gruppe abrufen
    public Set<Recipe> getGroupRecipes(Long groupId) {
        Group group = groupRepository.findById(groupId)
                .orElseThrow(() -> new RuntimeException("Gruppe nicht gefunden"));
        return group.getSharedRecipes().stream().map(GroupRecipe::getRecipe).collect(Collectors.toSet());
    }
}
