package com.example.hangry.services;

import org.springframework.stereotype.Service;
import java.util.Set;
import com.example.hangry.*;
@Service
public class GroupService {

    private final GroupRepository groupRepository;
    private final UserRepository userRepository;

    public GroupService(GroupRepository groupRepository, UserRepository userRepository) {
        this.groupRepository = groupRepository;
        this.userRepository = userRepository;
    }

    // Gruppe erstellen
    public Group createGroup(String name, String description) {
        Group group = new Group(name, description);
        return groupRepository.save(group);
    }

    // Gruppe beitreten
    public boolean joinGroup(Long userId, Long groupId) {
        User user = userRepository.findById(userId)
                .orElseThrow(() -> new RuntimeException("User nicht gefunden"));
        Group group = groupRepository.findById(groupId)
                .orElseThrow(() -> new RuntimeException("Gruppe nicht gefunden"));

        if (!group.getMembers().contains(user)) {
            group.getMembers().add(user);
            groupRepository.save(group);
            return true;
        }
        return false;
    }

    // Gruppe verlassen
    public boolean leaveGroup(Long userId, Long groupId) {
        User user = userRepository.findById(userId)
                .orElseThrow(() -> new RuntimeException("User nicht gefunden"));
        Group group = groupRepository.findById(groupId)
                .orElseThrow(() -> new RuntimeException("Gruppe nicht gefunden"));

        if (group.getMembers().contains(user)) {
            group.getMembers().remove(user);
            groupRepository.save(group);
            return true;
        }
        return false;
    }

    // Alle Mitglieder einer Gruppe abrufen
    public Set<User> getGroupMembers(Long groupId) {
        Group group = groupRepository.findById(groupId)
                .orElseThrow(() -> new RuntimeException("Gruppe nicht gefunden"));
        return group.getMembers();
    }
}
