package com.example.hangry.services;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.*;
import com.example.hangry.*;
@Service
public class IngredientService {

    @Autowired
    private IngredientRepository ingredientRepository;

    @Autowired
    private UserRepository userRepository;

    // Globale Zutaten abrufen
    public List<Ingredient> getGlobalIngredients() {
        return ingredientRepository.findByIsGlobal(true);
    }

    // Benutzerspezifische Zutaten abrufen
    public List<Ingredient> getUserIngredients(Long userId) {
        Optional<User> user = userRepository.findById(userId);
        if (user.isPresent()) {
            return ingredientRepository.findByUserId(userId);
        } else {
            throw new IllegalArgumentException("User not found with ID: " + userId);
        }
    }

    // Globale Zutat hinzufügen
    public Ingredient addGlobalIngredient(Ingredient ingredient) {
        ingredient.setGlobal(true); // Zutat als global markieren
        return ingredientRepository.save(ingredient);
    }

    // Benutzerdefinierte Zutat hinzufügen, nur wenn sie nicht global existiert
    public Ingredient addUserIngredient(Long userId, Ingredient ingredient) {
        // Zuerst prüfen, ob diese Zutat bereits global existiert
        boolean isGlobalIngredientExists = ingredientRepository.existsByNameAndIsGlobal(ingredient.getName(), true);

        if (isGlobalIngredientExists) {
            throw new IllegalArgumentException("Zutat existiert bereits als globale Zutat.");
        }

        Optional<User> user = userRepository.findById(userId);
        if (user.isPresent()) {
            ingredient.setGlobal(false); // Zutat als benutzerspezifisch markieren
            ingredient.setUser(user.get()); // Zutat dem Benutzer zuweisen
            return ingredientRepository.save(ingredient);
        } else {
            throw new IllegalArgumentException("User not found with ID: " + userId);
        }
    }
}
