package com.example.hangry.services;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import java.util.List;
import com.example.hangry.*;

@Service
public class LikeService {

    private final LikeRepository likeRepository;
    private final RecipeRepository recipeRepository;
    private final UserRepository userRepository;

    public LikeService(LikeRepository likeRepository, RecipeRepository recipeRepository, UserRepository userRepository) {
        this.likeRepository = likeRepository;
        this.recipeRepository = recipeRepository;
        this.userRepository = userRepository;
    }

    // Rezept liken
    public boolean likeRecipe(Long userId, Long recipeId) {
        User user = userRepository.findById(userId).orElseThrow();
        Recipe recipe = recipeRepository.findById(recipeId).orElseThrow();

        if (likeRepository.existsByUserAndRecipe(user, recipe)) {
            return false; // Bereits geliked
        }

        Like like = new Like();
        like.setUser(user);
        like.setRecipe(recipe);
        likeRepository.save(like);
        return true;
    }

    // Rezept entliken
    @Transactional
    public boolean unlikeRecipe(Long userId, Long recipeId) {
        User user = userRepository.findById(userId)
                .orElseThrow(() -> new RuntimeException("User nicht gefunden"));
        Recipe recipe = recipeRepository.findById(recipeId)
                .orElseThrow(() -> new RuntimeException("Rezept nicht gefunden"));

        // Prüfen, ob das Like existiert
        if (!likeRepository.existsByUserAndRecipe(user, recipe)) {
            return false; // Like existiert nicht
        }

        likeRepository.deleteByUserAndRecipe(user, recipe);
        return true;
    }


    // Anzahl der Likes für ein Rezept abrufen
    public long getLikeCount(Long recipeId) {
        Recipe recipe = recipeRepository.findById(recipeId).orElseThrow();
        return likeRepository.countByRecipe(recipe);
    }

    // Alle geliketen Rezepte eines Users abrufen
    public List<Recipe> getLikedRecipes(Long userId) {
        User user = userRepository.findById(userId).orElseThrow();
        List<Like> likes = likeRepository.findAllByUser(user);
        return likes.stream().map(Like::getRecipe).toList();
    }
}
