package com.example.hangry.services;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;

import java.util.Optional;
import com.example.hangry.*;
@Service
public class RecipeService {

    private final RecipeRepository recipeRepository;

    public RecipeService(RecipeRepository recipeRepository) {
        this.recipeRepository = recipeRepository;
    }

    // Alle Rezepte mit Pagination abrufen
    public Page<Recipe> getAllRecipes(Pageable pageable) {
        return recipeRepository.findAll(pageable);
    }

    // Einzelnes Rezept nach ID abrufen
    public Optional<Recipe> getRecipeById(Long id) {
        return recipeRepository.findById(id);
    }

    // Neues Rezept erstellen
    public Recipe createRecipe(Recipe recipe) {
        return recipeRepository.save(recipe);
    }

    // Rezept aktualisieren
    public Optional<Recipe> updateRecipe(Long id, Recipe recipeDetails) {
        return recipeRepository.findById(id).map(recipe -> {
            if (recipeDetails.getName() != null) recipe.setName(recipeDetails.getName());
            if (recipeDetails.getDescription() != null) recipe.setDescription(recipeDetails.getDescription());
            if (recipeDetails.getCategory() != null) recipe.setCategory(recipeDetails.getCategory());
            if (recipeDetails.getImageUrl() != null) recipe.setImageUrl(recipeDetails.getImageUrl());
            return recipeRepository.save(recipe);
        });
    }


    // Rezept löschen
    public boolean deleteRecipe(Long id) {
        if (recipeRepository.existsById(id)) {
            recipeRepository.deleteById(id);
            return true;
        }
        return false;
    }

    //Filter nach Kategorie
    public Page<Recipe> getRecipesByCategory(String category, Pageable pageable) {
        return recipeRepository.findByCategoryIgnoreCase(category, pageable);
    }

    //Filter nach Zutat
    public Page<Recipe> getRecipesByIngredient(String ingredient, Pageable pageable) {
        return recipeRepository.findByIngredient(ingredient, pageable);
    }

}
